
/**********************************************************************************

    ____  ____     ___  __ __  ___    __ __  ____  ____    ___  
   |    \|    \   /  _]|  |  ||   \  |  |  ||    ||    \  /   \ 
   |  o  )  _  | /  [_ |  |  ||    \ |  |  | |  | |  _  ||     |
   |   _/|  |  ||    _]|  |  ||  D  ||  |  | |  | |  |  ||  O  |
   |  |  |  |  ||   [_ |  :  ||     ||  :  | |  | |  |  ||     |
   |  |  |  |  ||     ||     ||     ||     | |  | |  |  ||     |
   |__|  |__|__||_____| \__,_||_____| \__,_||____||__|__| \___/ 

   PneuDuino is a toolkit for controlling inflatable actuators
   and prototyping interactions with shape-changing systems.

   Every slave board has a RGB led on the top right corner that communicates
   the state of this board.

   GREEN - baord running and connecting
   RED - board running, but not connected
   BLUE - board not running yet (usually after reset or power) or broken :(

   The boards addresses range from 1-12. 12 is reserved for IO Boards.
   There can ONLY BE ONE IO BOARD per system.

   The library offers functions that allow for controlling the valves and 
   accessing the pressure sensor :

   begin() - should be called at the beginning of setup()
   update() - should be called at the beginning of loop()

   void in(address, side) - inflates bag of board with defined address
   void out(address, side) - deflates bag of board with defined address
   int readPressure(address) - returns pressure of bag at defined address. 
                              Notice that a non-deflated bag still experiences 
                              athmospheric pressure and thus does not return 0.
   bool readButton(side) - returns button state of IO Board. 0 is top, 1 is bottom.
   int readPot() - returns potentiometer value of IO Board. 0 - 15.

   |||

   Accelerometer Sensor Example Code Information

   The Grove 6-Axis Accelerometer and Gyroscope is integrated with a 3-axis digital
   accelerometer and a 3-axis digital gyroscope. Using a digital LSM6DS3 chip, it features
   high sensitivity, green tech, and low noise interference. It can be configured to 
   different sensitivity levels for acceleration and different angular rate measurement ranges.

   This example code offers a couple implementation of the accelerometer. The first will just read
   the tilt level of the accelerometer on different axis to determine which valve to inflate.
   The second has a trigger acceleration in a certain direction that causes inflation to occur
   for 10 seconds.    

   |||

   Functions and Values

   air.initAcGy() - Initializes the accelerometer. 

   air.readAcGy[AXIS]() - Will read the acceleration in whichever axis given. 
   
**********************************************************************************/
#include <Wire.h>
#include <PneuDuinoExp.h>
PneuDuinoExp air = PneuDuinoExp();  //  Creating instance of PneuDuino class
int val = 0;
int x_axis = 0;
int y_axis = 0;
int z_axis = 0;

bool trigger = true;
bool inflate = false;
unsigned long previousMillis = 0;
const long maxtime = 10000;

void setup() {
  Serial.begin(9600); //  Initializing Serial communications
  while (!Serial);  //  ** WAITS UNTIL SERIAL WINDOW IS OPENED TO START EXECUTING **
  air.begin();  //  Initializes Pneuduino Setup
  air.initAcGy(); //  initializes accelerometer
}

void loop(){
  /*
  Serial.println(air.readAccY());
  y_axis = air.readAccY();  //  Read Accelerometer Data on y-axis and assigns to variable
  air.update();
  if (y_axis < `-3500){
    delay(50);
    air.in(10,RIGHT);
    delay(50);
    air.out(10,RIGHT);
  }
  if (y_axis > 3500){
    delay(50);
    air.in(10,LEFT);
    delay(50);
    air.out(10,LEFT);
  }
  */
  
  /*
  Serial.println(air.readAccX());
  x_axis = air.readAccX();
  if (x_axis < -3500){
    delay(50);
    air.in(6,RIGHT);
    delay(50);
    air.out(6,RIGHT);
  }
  if (x_axis > 3500){
    delay(50);
    air.in(6,LEFT);
    delay(50);
    air.out(6,LEFT);
  }
  */ 
  
  /*
  void loop() {
  air.update();
  Serial.println(air.readAccZ());
  unsigned long currentMillis = millis();
  if (currentMillis - previousMillis >= maxtime){
    previousMillis = currentMillis;
  }
  z_axis = air.readAccZ();
  if (z_axis < -10000){
    inflate = true;
  }

  if (inflate == true){
    if (currentMillis - previousMillis <= maxtime/10){
      trigger = true;
    }
    if (trigger == true){
      delay(10);
      air.in(6,LEFT);
      delay(10);
      air.out(6,LEFT);
    }
    if (currentMillis - previousMillis >= (maxtime-(maxtime/10))){
      trigger = false;
      inflate = false;
    }
  }
  */
}
